===============================
finchan_exts
===============================


.. image:: https://img.shields.io/pypi/v/finchan_exts.svg
        :target: https://pypi.python.org/pypi/finchan_exts

.. image:: https://img.shields.io/travis/qytz/finchan_exts.svg
        :target: https://travis-ci.org/qytz/finchan_exts

.. image:: https://readthedocs.org/projects/finchan_exts/badge/?version=latest
        :target: https://finchan_exts.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/qytz/finchan_exts/shield.svg
     :target: https://pyup.io/repos/github/qytz/finchan_exts/
     :alt: Updates


Some extensions for `finchan <https://github.com/qytz/finchan>`_

* Free software: Apache License 2.0
* Documentation: https://finchan_exts.readthedocs.io.
